==> wiki3_5_6.zip: wiki3_5_6/plugin/core/AdminFarmHandler.pm <==
###############################################################################
#
# FarmԤϥɥ顣
#
###############################################################################
package plugin::core::AdminFarmHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self  = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	$wiki->set_title("WikiFarm");
	if($wiki->get_CGI()->param("save") ne ""){
		return $self->save_config($wiki);
	} else {
		return $self->config_form($wiki);
	}
}

#==============================================================================
# ¸
#==============================================================================
sub save_config {
	my $self = shift;
	my $wiki = shift;
	
	my $cgi     = $wiki->get_CGI();
	my $create  = $cgi->param("create");
	my $remove  = $cgi->param("remove");
	my $usefarm = $cgi->param("usefarm");
	
	&Util::save_config_hash($wiki,$wiki->config('farmconf_file'),
	                        {create=>$create,remove=>$remove,usefarm=>$usefarm});
	
	$wiki->redirectURL($wiki->config('script_name')."?action=ADMINFARM");
	#return "WikiFarm¸ޤ";
}

#==============================================================================
# 
#==============================================================================
sub config_form {
	my $self = shift;
	my $wiki = shift;
	my $config = &Util::load_config_hash($wiki,$wiki->config('farmconf_file'));
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n";
	$buf   .= "<h2>WikiFarm</h2>\n";
	$buf   .= "  <h3>FarmѤ뤫ɤ</h3>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"radio\" name=\"usefarm\" value=\"0\""; if($config->{usefarm}==0){ $buf.= " checked"; } $buf.=">Ѥʤ\n";
	$buf   .= "  <input type=\"radio\" name=\"usefarm\" value=\"1\""; if($config->{usefarm}==1){ $buf.= " checked"; } $buf.=">Ѥ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <h3>Farmκ</h3>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"radio\" name=\"create\" value=\"0\""; if($config->{create}==0){ $buf.= " checked"; } $buf.=">ïǤǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"create\" value=\"1\""; if($config->{create}==1){ $buf.= " checked"; } $buf.=">Τ߲ǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"create\" value=\"2\""; if($config->{create}==2){ $buf.= " checked"; } $buf.=">ԤΤ߲ǽ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <h3>Farmκ</h3>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"radio\" name=\"remove\" value=\"0\""; if($config->{remove}==0){ $buf.= " checked"; } $buf.=">ïǤǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"remove\" value=\"1\""; if($config->{remove}==1){ $buf.= " checked"; } $buf.=">Τ߲ǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"remove\" value=\"2\""; if($config->{remove}==2){ $buf.= " checked"; } $buf.=">ԤΤ߲ǽ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <input type=\"submit\" name=\"save\" value=\"¸\">\n";
	$buf   .= "  <input type=\"reset\"  value=\"ꥻå\">\n";
	$buf   .= "  <input type=\"hidden\" name=\"action\" value=\"ADMINFARM\">\n";
	$buf   .= "</form>\n";
	
	return $buf;
}

1;

==> wiki3_5_11.zip: wiki3_5_11/plugin/core/AdminFarmHandler.pm <==
###############################################################################
#
# FarmԤϥɥ顣
#
###############################################################################
package plugin::core::AdminFarmHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self  = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	$wiki->set_title("WikiFarm");
	if($wiki->get_CGI()->param("save") ne ""){
		return $self->save_config($wiki);
	} else {
		return $self->config_form($wiki);
	}
}

#==============================================================================
# ¸
#==============================================================================
sub save_config {
	my $self = shift;
	my $wiki = shift;
	
	my $cgi           = $wiki->get_CGI();
	my $create        = $cgi->param("create");
	my $remove        = $cgi->param("remove");
	my $usefarm       = $cgi->param("usefarm");
	my $use_template  = $cgi->param("use_template");
	my $search_parent = $cgi->param("search_parent");
	my $hide_template = $cgi->param("hide_template");
	
	&Util::save_config_hash($wiki,$wiki->config('farmconf_file'),
		{create        => $create,
		 remove        => $remove,
		 usefarm       => $usefarm,
		 use_template  => $use_template,
		 search_parent => $search_parent,
		 hide_template => $hide_template});
	
	$wiki->redirectURL($wiki->config('script_name')."?action=ADMINFARM");
	#return "WikiFarm¸ޤ";
}

#==============================================================================
# 
#==============================================================================
sub config_form {
	my $self = shift;
	my $wiki = shift;
	my $config = &Util::load_config_hash($wiki,$wiki->config('farmconf_file'));
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n";
	$buf   .= "<h2>WikiFarm</h2>\n";
	$buf   .= "  <h3>FarmѤ뤫ɤ</h3>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"radio\" name=\"usefarm\" value=\"0\""; if($config->{usefarm}==0){ $buf.= " checked"; } $buf.=">Ѥʤ\n";
	$buf   .= "  <input type=\"radio\" name=\"usefarm\" value=\"1\""; if($config->{usefarm}==1){ $buf.= " checked"; } $buf.=">Ѥ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <h3>Farmκ</h3>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"radio\" name=\"create\" value=\"0\""; if($config->{create}==0){ $buf.= " checked"; } $buf.=">ïǤǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"create\" value=\"1\""; if($config->{create}==1){ $buf.= " checked"; } $buf.=">Τ߲ǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"create\" value=\"2\""; if($config->{create}==2){ $buf.= " checked"; } $buf.=">ԤΤ߲ǽ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <h3>Farmκ</h3>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"radio\" name=\"remove\" value=\"0\""; if($config->{remove}==0){ $buf.= " checked"; } $buf.=">ïǤǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"remove\" value=\"1\""; if($config->{remove}==1){ $buf.= " checked"; } $buf.=">Τ߲ǽ\n";
	$buf   .= "  <input type=\"radio\" name=\"remove\" value=\"2\""; if($config->{remove}==2){ $buf.= " checked"; } $buf.=">ԤΤ߲ǽ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <h3>Υƥץ졼</h3>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"checkbox\" name=\"use_template\" value=\"1\""; 
	          if($config->{use_template}==1){ $buf.= " checked"; } $buf.=">./templateڡ򥳥ԡ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"checkbox\" name=\"search_parent\" value=\"1\"";
	          if($config->{search_parent}==1){ $buf.= " checked"; } $buf.=">./templateʤ硢ƤˤΤܤäõ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <p>\n";
	$buf   .= "  <input type=\"checkbox\" name=\"hide_template\" value=\"1\"";
	          if($config->{hide_template}==1){ $buf.= " checked"; } $buf.=">Wikiΰ./templateɽʤ\n";
	$buf   .= "  </p>\n";
	$buf   .= "  <input type=\"submit\" name=\"save\" value=\"¸\">\n";
	$buf   .= "  <input type=\"reset\"  value=\"ꥻå\">\n";
	$buf   .= "  <input type=\"hidden\" name=\"action\" value=\"ADMINFARM\">\n";
	$buf   .= "</form>\n";
	
	return $buf;
}

1;
